@@ -5,13 +5,13 @@ pub struct PosixCategory;
 
 #[cfg(target_os = "unknown")]
 #[inline(always)]
-pub const fn is_would_block(_: i32) -> bool {
+pub fn is_would_block(_: i32) -> bool {
     false
 }
 
 #[cfg(not(target_os = "unknown"))]
 #[inline]
-pub const fn is_would_block(code: i32) -> bool {
+pub fn is_would_block(code: i32) -> bool {
     code == libc::EWOULDBLOCK || code == libc::EAGAIN
 }
 
